@@ -138,7 +138,7 @@ def exportQuotes(quotes, saveFile):
 			if i == 1:
 				save.write(quote)
 			else:
-				save.append(quote)
+				save.append(quote,newline=True)
 	except:
 		pass
 
