@@ -21,10 +21,10 @@ class File:
     def __init__(self, fileName, enc=0):
         self.fileName = fileName
         self.enc_dict = {0:None, 1:"utf8"}
-        # try:
-        self.encode = self.enc_options(enc)
-        # except:
-        #     self.encode = enc
+        try:
+            self.encode = self.enc_options(enc)
+        except:
+            self.encode = enc
 
     def enc_options(self, interger):
         return self.enc_dict[interger]
